@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013, 2014, 2015, 2016, 2017 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2013, 2014, 2015, 2016, 2017, 2018 Graeme Gott <graeme@gottcode.org>
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -105,7 +105,7 @@ WhiskerMenu::Window::Window() :
 	gtk_window_set_decorated(m_window, false);
 	gtk_window_set_skip_taskbar_hint(m_window, true);
 	gtk_window_set_skip_pager_hint(m_window, true);
-	gtk_window_set_type_hint(m_window, GDK_WINDOW_TYPE_HINT_DIALOG);
+	gtk_window_set_type_hint(m_window, GDK_WINDOW_TYPE_HINT_POPUP_MENU);
 	gtk_window_stick(m_window);
 	gtk_widget_add_events(GTK_WIDGET(m_window), GDK_BUTTON_PRESS_MASK | GDK_LEAVE_NOTIFY_MASK | GDK_STRUCTURE_MASK);
 	g_signal_connect_slot(m_window, "enter-notify-event", &Window::on_enter_notify_event, this);
@@ -114,6 +114,7 @@ WhiskerMenu::Window::Window() :
 	g_signal_connect_slot(m_window, "key-press-event", &Window::on_key_press_event, this);
 	g_signal_connect_slot(m_window, "key-press-event", &Window::on_key_press_event_after, this, true);
 	g_signal_connect_slot(m_window, "map-event", &Window::on_map_event, this);
+	g_signal_connect_slot(m_window, "state-flags-changed", &Window::on_state_flags_changed_event, this);
 	g_signal_connect_slot(m_window, "configure-event", &Window::on_configure_event, this);
 	g_signal_connect(m_window, "delete_event", G_CALLBACK(gtk_widget_hide_on_delete), NULL);
 
@@ -835,6 +836,19 @@ gboolean WhiskerMenu::Window::on_map_event(GtkWidget*, GdkEvent*)
 
 //-----------------------------------------------------------------------------
 
+gboolean WhiskerMenu::Window::on_state_flags_changed_event(GtkWidget* widget, GtkStateFlags)
+{
+	// Refocus and raise window if visible
+	if (gtk_widget_get_visible(widget))
+	{
+		gtk_window_present(m_window);
+	}
+
+	return false;
+}
+
+//-----------------------------------------------------------------------------
+
 gboolean WhiskerMenu::Window::on_configure_event(GtkWidget*, GdkEvent* event)
 {
 	GdkEventConfigure* configure_event = reinterpret_cast<GdkEventConfigure*>(event);
